@@ -1156,25 +1156,48 @@ int set_job_env(
     strcat(job_env,c);
     }
 
-  if (qsub_host[0] != '\0')
+  if (qsub_host[0] != '\0' ||
+      (rc = gethostname(qsub_host, PBS_MAXHOSTNAME + 1)) == 0)
     {
-    strcat(job_env,",PBS_O_HOST=");
-    strcat(job_env,qsub_host);
+    if ((rc = get_fullhostname(qsub_host, qsub_host, PBS_MAXHOSTNAME, NULL)) == 0)
+      {
+      strcat(job_env,",PBS_O_HOST=");
+      strcat(job_env,qsub_host);
+      }
     }
 
-  if ((server_host[0] != '\0') ||
-      ((rc = gethostname(server_host, PBS_MAXHOSTNAME + 1)) == 0))
+  if (rc != 0)
     {
-    if ((rc = get_fullhostname(server_host, server_host, PBS_MAXHOSTNAME, NULL)) == 0)
+    fprintf(stderr,"qsub: cannot get (full) local host name\n");
+    exit(3);
+    }
+
+  if (server_host[0] != '\0')
+    {
+    if (get_fullhostname(server_host, server_host, PBS_MAXHOSTNAME, NULL) == 0)
       {
       strcat(job_env,",PBS_SERVER=");
       strcat(job_env,server_host);
-
-      if (qsub_host[0] == '\0')
-        {
-        strcat(job_env,",PBS_O_HOST=");
-        strcat(job_env,server_host);
-        }
+      }
+    else
+      {
+      fprintf(stderr,"qsub: cannot get full server host name\n");
+      exit(3);
+      }
+    }
+  else
+    {
+    c = pbs_default();
+    if (*c != '\0')
+      {
+      strncpy(server_host, c, sizeof(server_host));
+      strcat(job_env,",PBS_SERVER=");
+      strcat(job_env,server_host);
+      }
+    else
+      {
+      strcat(job_env,",PBS_SERVER=");
+      strcat(job_env,qsub_host);
       }
     }
 
@@ -1184,13 +1207,6 @@ int set_job_env(
     strcat(job_env,owner_uid);
     }
 
-  if (rc != 0)
-    {
-    fprintf(stderr,"qsub: cannot get full local host name\n");
-
-    exit(3);
-    }
-
   /* load init dir into env if specified */
 
   if (PBS_InitDir[0] != '\0')
@@ -2020,9 +2036,9 @@ void no_suspend(
   int sig)
 
   {
-  printf("Sorry, you cannot suspend qsub until the job is started\n");
+  fprintf(stderr, "Sorry, you cannot suspend qsub until the job is started\n");
 
-  fflush(stdout);
+  fflush(stderr);
   }
 
 
@@ -3305,16 +3321,26 @@ int process_opts(
             {
             if_cmd_line(Depend_opt)
               {
+              int rtn = 0;
               Depend_opt = passet;
 
               pdepend = malloc(PBS_DEPEND_LEN);
 
               if ((pdepend == NULL) ||
-                   parse_depend_list(valuewd,pdepend,PBS_DEPEND_LEN))
+                   (rtn = parse_depend_list(valuewd,pdepend,PBS_DEPEND_LEN)))
                 {
                 /* cannot parse 'depend' value */
 
-                fprintf(stderr,"qsub: illegal -W value\n");
+                if (rtn == 2)
+                  {
+                  fprintf(stderr,"qsub: -W value exceeded max length (%d)\n",
+                    PBS_DEPEND_LEN);
+                  }
+                else
+                  {
+                  fprintf(stderr,"qsub: illegal -W value\n");
+                  }
+
                 errflg++;
 
                 break;
@@ -4029,7 +4055,7 @@ int main(
 
     if ((param_val = get_param("QSUBSENDUID", config_buf)) != NULL)
       {
-      sprintf(owner_uid, "%d", getuid());
+      sprintf(owner_uid, "%d", (int)getuid());
       }
 
     if ((param_val = get_param("XAUTHPATH", config_buf)) != NULL)
