@@ -83,6 +83,7 @@
  * Functions included are:
  * log_open()
  * log_err()
+ * log_ext()
  * log_record()
  * log_close()
  * log_roll()
@@ -105,6 +106,7 @@
 #include <string.h>
 #include <unistd.h>
 #include <errno.h>
+#include <dirent.h>
 
 #include "log.h"
 #if SYSLOG
@@ -149,6 +151,10 @@ static char *class_names[] =
 
 /* External functions called */
 
+/* local prototypes */
+const char *log_get_severity_string(int);
+
+
 /*
  * mk_log_name - make the log name used by MOM
  * based on the date: yyyymmdd
@@ -325,14 +331,49 @@ void log_err(
   char *routine, /* I */
   char *text)    /* I */
 
+  {
+  log_ext(errnum,routine,text,LOG_ERR);
+
+  return;
+  }  /* END log_err() */
+
+
+
+
+/*
+ *  log_ext (log extended) - log message to syslog (if available) and to the TORQUE log.
+ *
+ *  The error is recorded to the TORQUE log file and to syslogd if it is
+ *	available.  If the error file has not been opened and if syslog is
+ *	not defined, then the console is opened.
+
+ *  Note that this function differs from log_err in that you can specify a severity
+ *  level that will accompany the message in the syslog (see 'manpage syslog' for a list
+ *  of severity/priority levels). This function, is in fact, used by log_err--it just uses
+ *  a severity level of LOG_ERR
+ */
+
+void log_ext(
+
+  int   errnum,   /* I (errno or PBSErrno) */
+  char *routine,  /* I */
+  char *text,     /* I */
+  int   severity) /* I */
+
   {
   char  buf[LOG_BUF_SIZE];
 
-  char *EPtr;
+  char *EPtr = NULL;
 
   char  EBuf[1024];
 
-  int   i;
+  char  tmpLine[2048];
+
+  const char *SeverityText = NULL;
+
+  tmpLine[0] = '\0';
+
+  EBuf[0] = '\0';
 
   if (errnum == -1)
     {
@@ -359,19 +400,18 @@ void log_err(
       EPtr = EBuf;
       }
 
-    sprintf(buf, "%s (%d) in ",
-
+    sprintf(tmpLine,"%s (%d) in ", 
             EPtr,
             errnum);
     }
 
-  strcat(buf, routine);
+  SeverityText = log_get_severity_string(severity);
 
-  strcat(buf, ", ");
-
-  i = LOG_BUF_SIZE - (int)strlen(buf) - 2;
-
-  strncat(buf, text, i);
+  snprintf(buf,sizeof(buf),"%s::%s%s, %s",
+    SeverityText,
+    tmpLine,
+    routine,
+    text);
 
   buf[LOG_BUF_SIZE - 1] = '\0';
 
@@ -406,12 +446,67 @@ void log_err(
     syslogopen = 1;
     }
 
-  syslog(LOG_ERR | LOG_DAEMON, "%s", buf);
+  syslog(severity|LOG_DAEMON,"%s",buf);
 
 #endif /* SYSLOG */
 
   return;
-  }  /* END log_err() */
+  }  /* END log_ext() */
+
+
+
+/**
+ * Returns a string to represent the syslog severity-level given.
+ */
+
+const char *log_get_severity_string(
+
+  int severity)
+
+  {
+  const char *result = NULL;
+
+  /* We can't just index into an array to get the strings, as we don't always
+   * have control over what the value of the LOG_* consts are */
+
+  switch (severity)
+    {
+    case LOG_EMERG:
+      result = "LOG_EMERGENCY";
+      break;
+    
+    case LOG_ALERT:
+      result = "LOG_ALERT";
+      break;
+
+    case LOG_CRIT:
+      result = "LOG_CRITICAL";
+      break;
+
+    case LOG_ERR:
+      result = "LOG_ERROR";
+      break;
+
+    case LOG_WARNING:
+      result = "LOG_WARNING";
+      break;
+
+    case LOG_NOTICE:
+      result = "LOG_NOTICE";
+      break;
+
+    case LOG_DEBUG:
+      result = "LOG_DEBUG";
+      break;
+
+    case LOG_INFO:
+    default:
+      result = "LOG_INFO";
+      break;
+    }
+
+  return(result);
+  }  /* END log_get_severity_string() */
 
 
 
@@ -585,6 +680,109 @@ void log_close(
 
 
 
+/**
+ * log_remove_old - Removes log files older than a given time.
+ * This function removes files from the given path if they were last modified after ExpireTime.
+ *
+ * Note that this function will skip over special filenames like '.' and '..'.
+ *
+ * @param DirPath (I)
+ * @param ExpireTime (I, how old the file must be to be removed, in seconds)
+ * if (Expiretime == 0), nothing will be removed
+ * @return 0 on success, non-zero otherwise
+ */
+
+int log_remove_old(
+
+  char  *DirPath,     /* I (path in which we're removing files)*/
+  unsigned long ExpireTime)   /* I (how old the file must be to be removed, in seconds) */
+
+  {
+  char tmpPath[MAX_PATH_LEN];
+ 
+  DIR *DirHandle;
+  struct dirent *FileHandle;
+  struct stat sbuf;
+  unsigned long FMTime;
+  unsigned long TTime;
+ 
+  int IsDir = FALSE;
+  TTime = time((time_t *)NULL);
+ 
+  /* check the input for an empty path */
+  if ((DirPath == NULL) || (DirPath[0] == '\0'))
+    {
+    return(-1);
+    }
+
+  if (ExpireTime == 0)
+    {
+    return(0);
+    }
+
+  /* open directory for reading */
+      
+  DirHandle = opendir(DirPath);
+
+  /* fail if path couldn't be opened */  
+  if (DirHandle == (DIR *)NULL)
+    {
+    return(-1);
+    }
+
+  FileHandle = readdir(DirHandle);
+  
+  while (FileHandle != (struct dirent *)NULL)
+    {    
+    /* attempt to delete old files */
+
+    if (!strcmp(FileHandle->d_name,".") ||
+        !strcmp(FileHandle->d_name,".."))
+      {
+      /* skip special file names */
+
+      FileHandle = readdir(DirHandle);
+
+      continue;
+      }
+
+    snprintf(tmpPath,sizeof(tmpPath),"%s/%s",
+      DirPath,
+      FileHandle->d_name);
+
+    if (stat(tmpPath,&sbuf) == -1) 
+      {
+      /* -1 is the failure value for stat */
+
+      FMTime = 0;
+
+      FileHandle = readdir(DirHandle);
+
+      continue;
+      }
+
+    /* set FMTime's value */
+    FMTime = (unsigned long)sbuf.st_mtime;
+    
+    if ((IsDir == FALSE) &&
+        (TTime - FMTime) > ExpireTime)
+      {
+      /* file is too old - delete it */
+
+      remove(tmpPath);
+      }
+
+    FileHandle = readdir(DirHandle);
+    } /* end file checking while loop */
+
+  closedir(DirHandle);
+
+  return(0);
+  }  /* END log_remove_ld() */
+
+
+
+
 
 
 void log_roll(
