@@ -195,7 +195,9 @@ int client_to_svr(
   struct sockaddr_in remote;
   int                sock;
   unsigned short     tryport;
+#ifndef NOPRIVPORTS
   int                flags;
+#endif /* !NOPRIVPORTS */
   int                one = 1;
 
   int                trycount;
@@ -205,6 +207,9 @@ int client_to_svr(
 
   errno = 0;
 
+  memset(&local, 0, sizeof(local));
+  memset(&remote, 0, sizeof(remote));
+
   local.sin_family      = AF_INET;
 
   local.sin_addr.s_addr = 0;
@@ -213,7 +218,9 @@ int client_to_svr(
 
   tryport = IPPORT_RESERVED - 1;
 
+#ifndef NOPRIVPORTS
 retry:  /* retry goto added (rentec) */
+#endif /* !NOPRIVPORTS */
 
   /* get socket */
 
