@@ -292,19 +292,20 @@ static void pelogalm(
  *  - argv[1] is the jobid
  *  - argv[2] is the user's name
  *  - argv[3] is the user's group name
- *              - argv[4] is the job name
+ *  - argv[4] is the job name
  *  - the input file is an architecture-dependent file
  *  - the output and error are the job's output and error
  * The epilogue also has:
- *  - argv[5] is the session id
- *  - argv[6] is the list of resource limits specified
- *  - argv[7] is the list of resources used
- *  - argv[8] is the queue in which the job resides
- *  - argv[9] is the account under which the job run
- *      The prologue also has:
- *              - argv[5] is the list of resource limits specified
- *              - argv[6] is the queue in which the job resides
- *              - argv[7] is the account under which the job is run
+ *   - argv[5] is the session id
+ *   - argv[6] is the list of resource limits specified
+ *   - argv[7] is the list of resources used
+ *   - argv[8] is the queue in which the job resides
+ *   - argv[9] is the account under which the job run
+ *   - argv[10] is the job's exit status 
+ * The prologue also has:
+ *   - argv[5] is the list of resource limits specified
+ *   - argv[6] is the queue in which the job resides
+ *   - argv[7] is the account under which the job is run
  */
 
 int run_pelog(
@@ -318,7 +319,7 @@ int run_pelog(
   char *id = "run_pelog";
 
   struct sigaction act, oldact;
-  char  *arg[11];
+  char  *arg[12];
   int   fds1 = 0;
   int   fds2 = 0;
   int   fd_input;
@@ -327,6 +328,7 @@ int run_pelog(
 
   struct stat sbuf;
   char   sid[20];
+  char   exit_stat[11];
   int    waitst;
   int    isjoined;  /* boolean */
   char   buf[MAXPATHLEN + 1024];
@@ -374,9 +376,11 @@ int run_pelog(
     rc = stat(pelog,&sbuf);
     }
 
+  printf("pelog: %s\n", pelog);
+
   if (rc == -1)
     {
-    if (errno == ENOENT)
+    if (errno == ENOENT || errno == EBADF)
       {
       /* prolog script does not exist */
 
@@ -384,10 +388,12 @@ int run_pelog(
         {
         static char tmpBuf[1024];
 
-        sprintf(log_buffer, "%s script '%s' does not exist (cwd: %s)",
+        sprintf(log_buffer, "%s script '%s' for job %s does not exist (cwd: %s,pid: %d)",
           PPEType[which],
           (pelog != NULL) ? pelog : "NULL",
-          getcwd(tmpBuf, sizeof(tmpBuf)));
+          (pjob != NULL) ? pjob->ji_qs.ji_jobid : "NULL",
+          getcwd(tmpBuf, sizeof(tmpBuf)),
+          getpid());
 
         log_record(PBSEVENT_SYSTEM, 0, id, log_buffer);
         }
@@ -400,11 +406,12 @@ int run_pelog(
 
   if (LOGLEVEL >= 5)
     {
-    sprintf(log_buffer, "running %s script '%s'",
+    sprintf(log_buffer,"running %s script '%s' for job %s",
       PPEType[which],
-      (pelog != NULL) ? pelog : "NULL");
+      (pelog != NULL) ? pelog : "NULL",
+      pjob->ji_qs.ji_jobid);
 
-    log_err(-1,id,log_buffer);  /* not actually an error--but informational */
+    log_ext(-1,id,log_buffer,LOG_DEBUG);  /* not actually an error--but informational */
     }
 
   /* script must be owned by root, be regular file, read and execute by user *
@@ -707,15 +714,18 @@ int run_pelog(
 
       sprintf(sid, "%ld",
               pjob->ji_wattr[(int)JOB_ATR_session_id].at_val.at_long);
+      sprintf(exit_stat,"%d",
+              pjob->ji_qs.ji_un.ji_exect.ji_exitstat);
 
       arg[5] = sid;
       arg[6] = resc_to_string(pjob, (int)JOB_ATR_resource, resc_list, sizeof(resc_list));
       arg[7] = resc_to_string(pjob, (int)JOB_ATR_resc_used, resc_used, sizeof(resc_used));
       arg[8] = pjob->ji_wattr[(int)JOB_ATR_in_queue].at_val.at_str;
       arg[9] = pjob->ji_wattr[(int)JOB_ATR_account].at_val.at_str;
-      arg[10] = NULL;
+      arg[10] = exit_stat;
+      arg[11] = NULL;
 
-      LastArg = 10;
+      LastArg = 11;
       }
     else
       {
@@ -930,7 +940,7 @@ int run_pelog(
         {
         char *envstr;
 
-        envstr = malloc((strlen(vstrs->as_string[j])) * sizeof(char));
+        envstr = malloc((strlen(vstrs->as_string[j]) + 1) * sizeof(char));
 
         if (envstr != NULL)
           {
