@@ -136,8 +136,10 @@ extern int mkdirtree(
 extern int TTmpDirName(job*, char *);
 #endif /* HAVE_WORDEXP */
 
+
 /* External Global Data Items */
 
+extern unsigned int alarm_time;
 extern unsigned int default_server_port;
 extern int  exiting_tasks;
 extern tlist_head svr_alljobs;
@@ -605,6 +607,13 @@ static int return_file(
 
   filename = std_file_name(pjob, which, &amt); /* amt is place holder */
 
+  /* We need to check for NULL which may be returned */
+  
+  if (filename == NULL)
+    {
+    return(-1);
+    }  
+
   if (strcmp(filename, "/dev/null") == 0)
     {
     return(0);
@@ -767,6 +776,21 @@ static int told_to_cp(
       {
       if (wchost_match(host, pcphosts[nh].cph_hosts))
         {
+
+        if (LOGLEVEL >= 5)
+          {
+          sprintf(log_buffer, "host '%s' pcphosts[%d].cph_hosts: %s",
+                  host,
+                  nh,
+                  pcphosts[nh].cph_hosts);
+
+          log_record(
+            PBSEVENT_SYSTEM,
+            PBS_EVENTCLASS_SERVER,
+            (char *)id,
+            log_buffer);
+          }
+
         i = strlen(pcphosts[nh].cph_from);
 
         if (strncmp(pcphosts[nh].cph_from, oldpath, i) == 0)
@@ -1125,12 +1149,14 @@ int message_job(
 
   rc = PBSE_NONE;
 
+  alarm(alarm_time);
   if (write(fds, text, len) != len)
     {
     log_err(errno, "message_job", "unable to write message to job");
 
     rc = PBSE_INTERNAL;
     }
+  alarm(0);
 
   if (close(fds) != 0)
     {
@@ -1251,6 +1277,8 @@ const char *TJobAttr[] =
   "start_count",
   "chkptdir",
   "chkptname",
+  "comp_time",
+  "reported",
   "job_type",
   NULL
   };
@@ -1987,7 +2015,8 @@ void req_signaljob(
 
   numprocs = kill_job(pjob, sig, id, "killing job");
 
-  if ((numprocs == 0) && ((sig == 0)||(sig == SIGKILL)))
+  if ((numprocs == 0) && ((sig == 0)||(sig == SIGKILL)) &&
+    (pjob->ji_qs.ji_substate != JOB_SUBSTATE_OBIT))
     {
     /* SIGNUL and no procs found, force job to exiting */
     /* force issue of (another) job obit */
@@ -2425,7 +2454,7 @@ static int del_files(
 
       default:
 
-        sprintf(log_buffer, ">>> failed to delete files, expansion of %s failed",
+        sprintf(log_buffer, "*** failed to delete files, expansion of %s failed",
                 path);
 
         add_bad_list(pbadfile, log_buffer, 1);
@@ -2659,6 +2688,10 @@ static int sys_copy(
   static char *id = "sys_copy";
   int loop;
   int rc;
+#ifdef UofU
+  int cpid;
+  int cp_timeout = 0;
+#endif
 
   sprintf(rcperr, "%srcperr.%ld",
           path_spool,
@@ -2685,7 +2718,7 @@ static int sys_copy(
             ag2,
             ag3);
 
-    log_err(-1, id, log_buffer);
+    log_ext(-1, id, log_buffer, LOG_DEBUG);
     }
 
   for (loop = 1;loop < 4;++loop)
@@ -2694,7 +2727,89 @@ static int sys_copy(
       {
       /* Parent - wait for copy to complete */
 
+#ifdef UofU
+      cpid = rc;
+      while (TRUE)
+        {
+        i = waitpid(-1, &rc, WNOHANG);
+        if (i > 0)
+          {      
+          /* for a cp command there should only be one pid that we see */
+
+          if (LOGLEVEL >= 8)
+            {
+            sprintf(log_buffer, "waitpid returned for pid (%d) rc (%d)",
+                  i, rc);
+            log_err(-1, id, log_buffer);
+            }
+          break;
+          }
+        else if (i == 0)
+          {
+          cp_timeout++;
+          if ((cp_timeout % 30 == 0) && (LOGLEVEL >= 8))
+            {
+            sprintf(log_buffer, "waitpid cp_timeout (%d)",
+                  cp_timeout);
+            log_err(-1, id, log_buffer);
+            }
+
+          /* check if the cp command pid is still active */
+
+          if (kill(cpid,0) == -1)
+            {
+            sprintf(log_buffer, "pid (%d) no longer active after waitpid, cp_timeout (%d)",
+                  cpid, cp_timeout);
+            log_err(-1, id, log_buffer);
+           
+            /* do we assume it is a failure? */
+
+            /* set to trigger error on wait failure */
+
+            i = -1;
+            break;         
+            }
+
+          /* If we eventually timeout does it mean we succeeded or failed? */
+
+          if (cp_timeout > 900)
+            {
+            sprintf(log_buffer, "giving up on waitpid after %d seconds",
+                  cp_timeout);
+            log_err(-1, id, log_buffer);
+
+            /* set to trigger error on wait failure */
+
+            i = -1;
+            break;         
+            }
+
+          sleep(1);
+          continue;
+          }
+        else if (errno == EINTR)
+          {
+          if (LOGLEVEL >= 8)
+            {
+            sprintf(log_buffer, "EINTR from waitpid");
+            log_err(-1, id, log_buffer);
+            }
+          continue;
+          }
+        else
+          {
+          sprintf(log_buffer, "errno (%d) returned from waitpid",
+                errno);
+          log_err(-1, id, log_buffer);
+
+          /* set to trigger error on wait failure */
+          i = -1;
+          break;
+          }
+        } 
+#else
       while (((i = wait(&rc)) < 0) && (errno == EINTR));
+#endif
 
       if (i == -1)
         {
@@ -2704,6 +2819,16 @@ static int sys_copy(
         {
         if ((rc = WEXITSTATUS(rc)) == 0)
           {
+          if (LOGLEVEL >= 8)
+            {
+            sprintf(log_buffer, "return code (%d) from copy: %s %s %s %s",
+                  rc,
+                  ag0,
+                  ag1,
+                  ag2,
+                  ag3);
+            log_err(-1, id, log_buffer);
+            }
           return(rc);          /* good,  stop now */
           }
         }
@@ -2715,10 +2840,23 @@ static int sys_copy(
         {
         rc = (40000 + WTERMSIG(rc)); /* 400xx is signaled */
         }
+      if (LOGLEVEL >= 8)
+        {
+        sprintf(log_buffer, "return code (%d) from copy: %s %s %s %s",
+              rc,
+              ag0,
+              ag1,
+              ag2,
+              ag3);
+        log_err(-1, id, log_buffer);
+        }
       }
     else if (rc < 0)
       {
       rc = errno + 10000; /* error on fork (100xx), retry */
+      sprintf(log_buffer,"%s: fork failure (%d) AG2 (%s) AG3 (%s)\n",
+        id, errno, ag2, ag3);
+      log_err(errno, id, log_buffer);
       }
     else
       {
@@ -2752,6 +2890,16 @@ static int sys_copy(
         }
 
       /* NOTE:  arg2 should be source, arg3 should be destination */
+      if (LOGLEVEL >= 8)
+        {
+        sprintf(log_buffer, "execling copy command pid (%d): %s %s %s %s",
+              getpid(),
+              ag0,
+              ag1,
+              ag2,
+              ag3);
+        log_err(-1, id, log_buffer);
+        }
 
       execl(ag0, ag0, ag1, ag2, ag3, NULL);
 
@@ -3033,6 +3181,8 @@ void req_cpyfile(
 
       log_err(errno,id,log_buffer);
 
+      bad_files = 1;
+
       goto error;
       }
 
@@ -3055,6 +3205,8 @@ void req_cpyfile(
 
           log_err(errno,id,log_buffer);
 
+          bad_files = 1;
+
           goto error;
           }
 
@@ -3069,6 +3221,12 @@ void req_cpyfile(
     }
   else
     {
+    if (LOGLEVEL >= 8)
+      {
+      sprintf(log_buffer,"%s: %s init user environment\n",
+        id, preq->rq_ind.rq_cpyfile.rq_jobid);
+      log_err(-1, id, log_buffer);
+      }
     InitUserEnv(pjob, NULL, NULL, NULL, NULL);
 
     *(vtable.v_envp + vtable.v_used) = NULL;
@@ -3196,6 +3354,12 @@ void req_cpyfile(
 
         strncpy(localname, pair->fp_local, sizeof(localname) - 1);  /* from location */
         }
+      if (LOGLEVEL >= 8)
+        {
+        sprintf(log_buffer,"%s: %s stage out (%s) remote file (%d) localfile (%s)\n",
+          id, preq->rq_ind.rq_cpyfile.rq_jobid, prmt, rmtflag, localname);
+        log_err(-1, id, log_buffer);
+        }
 
 #if SRFS
       /* Is this file part of $BIGDIR or $FASTDIR ? */
@@ -3382,6 +3546,12 @@ nextword:
 
       continue;
       }
+    if (LOGLEVEL >= 8)
+      {
+      sprintf(log_buffer,"%s: %s doing sys_copy (%d) ARG2 (%s) remote (%d) ARG3 (%s)\n",
+        id, preq->rq_ind.rq_cpyfile.rq_jobid, getpid(), arg2, rmtflag, arg3);
+      log_err(-1, id, log_buffer);
+      }
 
     if ((rc = sys_copy(rmtflag, arg2, arg3, preq->rq_conn)) != 0)
       {
@@ -3403,7 +3573,7 @@ nextword:
 
       if ((fp = fopen(rcperr, "r")) != NULL)
         {
-        add_bad_list(&bad_list, ">>> error from copy", 1);
+        add_bad_list(&bad_list, "*** error from copy", 1);
 
         while (fgets(log_buffer, LOG_BUF_SIZE, fp) != NULL)
           {
@@ -3417,7 +3587,7 @@ nextword:
 
         fclose(fp);
 
-        add_bad_list(&bad_list, ">>> end error output", 1);
+        add_bad_list(&bad_list, "*** end error output", 1);
         }
 
 #ifdef HAVE_WORDEXP
@@ -3474,6 +3644,12 @@ error:
     else
       {
       /* Copy in/out succeeded */
+    if (LOGLEVEL >= 8)
+      {
+      sprintf(log_buffer,"%s: %s sys_copy suceeded ARG2 (%s) ARG3 (%s)\n",
+        id, preq->rq_ind.rq_cpyfile.rq_jobid, arg2, arg3);
+      log_err(-1, id, log_buffer);
+      }
 
       if (dir == STAGE_DIR_OUT)
         {
@@ -3512,6 +3688,12 @@ error:
 
 #endif
 
+  if (LOGLEVEL >= 8)
+    {
+    sprintf(log_buffer,"%s: %s replying with %s\n",
+      id, preq->rq_ind.rq_cpyfile.rq_jobid, bad_files == 1? "Failure":"ACK");
+    log_err(-1, id, log_buffer);
+    }
   if (bad_files)
     {
     reply_text(preq, PBSE_NOCOPYFILE, bad_list);
@@ -3520,6 +3702,12 @@ error:
     {
     reply_ack(preq);
     }
+  if (LOGLEVEL >= 8)
+    {
+    sprintf(log_buffer,"%s: %s reply complete\n",
+      id, preq->rq_ind.rq_cpyfile.rq_jobid);
+    log_err(-1, id, log_buffer);
+    }
 
   /* we are the child, exit not return */
 
