@@ -146,8 +146,10 @@ extern char *msg_illregister;
 extern char *msg_registerdel;
 extern char *msg_registerrel;
 extern char *msg_regrej;
+extern char *msg_badstate;
 extern char  log_buffer[];
-
+extern int   LOGLEVEL;
+extern char *PJobState[];
 
 
 
@@ -217,9 +219,56 @@ void req_register(
     return;
     }
 
+  type = preq->rq_ind.rq_register.rq_dependtype;
+
+  if (((pjob->ji_qs.ji_state == JOB_STATE_COMPLETE) ||
+    (pjob->ji_qs.ji_state == JOB_STATE_EXITING)) &&
+    ((type = JOB_DEPEND_TYPE_AFTERSTART) ||
+    (type = JOB_DEPEND_TYPE_AFTERANY) ||
+    ((type = JOB_DEPEND_TYPE_AFTEROK) && (pjob->ji_qs.ji_un.ji_exect.ji_exitstat == 0)) ||
+    ((type = JOB_DEPEND_TYPE_AFTERNOTOK) && (pjob->ji_qs.ji_un.ji_exect.ji_exitstat != 0))))
+    {
+    if (LOGLEVEL >= 8)
+      {
+      sprintf(log_buffer,"Dependency requested for %s job, parent job %s, child job %s",
+        PJobState[pjob->ji_qs.ji_state],
+        preq->rq_ind.rq_register.rq_parent,
+        preq->rq_ind.rq_register.rq_child);
+
+      log_event(
+        PBSEVENT_JOB,
+        PBS_EVENTCLASS_JOB,
+        pjob->ji_qs.ji_jobid,
+        log_buffer);
+      }
+
+      log_event(
+        PBSEVENT_DEBUG,
+        PBS_EVENTCLASS_JOB,
+        preq->rq_ind.rq_register.rq_parent,
+        msg_badstate);
+
+      req_reject(PBSE_BADSTATE, 0, preq, NULL, NULL);
+
+      return;
+    }
+
+  if (LOGLEVEL >= 8)
+    {
+    sprintf(log_buffer,"Dependency requested parent job %s state (%s), child job %s",
+      preq->rq_ind.rq_register.rq_parent,
+      PJobState[pjob->ji_qs.ji_state],
+      preq->rq_ind.rq_register.rq_child);
+
+    log_event(
+      PBSEVENT_JOB,
+      PBS_EVENTCLASS_JOB,
+      pjob->ji_qs.ji_jobid,
+      log_buffer);
+    }
+
   pattr = &pjob->ji_wattr[(int)JOB_ATR_depend];
 
-  type = preq->rq_ind.rq_register.rq_dependtype;
   pjob->ji_modified = 1;
 
   /* more of the server:port fix kludge */
@@ -604,7 +653,10 @@ static void post_doq(
       strcat(log_buffer, "\n");
       strcat(log_buffer, "Job held for unknown job dep, use 'qrls' to release");
 
-      svr_mailowner(pjob, MAIL_ABORT, MAIL_FORCE, log_buffer);
+      if (preq->rq_reply.brp_code != PBSE_BADSTATE)
+        {
+        svr_mailowner(pjob, MAIL_ABORT, MAIL_FORCE, log_buffer);
+        }
 
       pattr = &pjob->ji_wattr[(int)JOB_ATR_depend];
 
@@ -613,9 +665,12 @@ static void post_doq(
         {
         del_depend_job(pdjb);
 
-        pjob->ji_wattr[(int)JOB_ATR_hold].at_val.at_long |= HOLD_u;
-        pjob->ji_wattr[(int)JOB_ATR_hold].at_flags |= ATR_VFLAG_SET;
-        pjob->ji_modified = 1;
+        if (preq->rq_reply.brp_code != PBSE_BADSTATE)
+          {
+          pjob->ji_wattr[(int)JOB_ATR_hold].at_val.at_long |= HOLD_u;
+          pjob->ji_wattr[(int)JOB_ATR_hold].at_flags |= ATR_VFLAG_SET;
+          pjob->ji_modified = 1;
+          }
 
         set_depend_hold(pjob, pattr);
         }
@@ -1216,6 +1271,15 @@ static void set_depend_hold(
 
       /* newstate is job's 'natural state - ie, what it would be if dependency did not exist */
 
+      if (LOGLEVEL >= 8)
+        {
+        log_event(
+          PBSEVENT_JOB,
+          PBS_EVENTCLASS_JOB,
+          pjob->ji_qs.ji_jobid,
+          "Clearing HOLD_s due to dependencies\n");
+        }
+
       svr_evaljobstate(pjob, &newstate, &newsubst, 0);
 
       svr_setjobstate(pjob, newstate, newsubst);
@@ -1228,6 +1292,15 @@ static void set_depend_hold(
     pjob->ji_wattr[(int)JOB_ATR_hold].at_val.at_long |= HOLD_s;
     pjob->ji_wattr[(int)JOB_ATR_hold].at_flags |= ATR_VFLAG_SET;
 
+    if (LOGLEVEL >= 8)
+      {
+      log_event(
+        PBSEVENT_JOB,
+        PBS_EVENTCLASS_JOB,
+        pjob->ji_qs.ji_jobid,
+        "Setting HOLD_s due to dependencies\n");
+      }
+
     svr_setjobstate(pjob, JOB_STATE_HELD, substate);
     }
 
@@ -1785,12 +1858,15 @@ int decode_depend(
 
 
 /*
- * cpy_jobsvr() - a version of strcpy() that watches for an embedded colon
+ * cpy_jobsvr() - a version of strcat() that watches for an embedded colon
  * and escapes it with a leading blackslash.  This is needed because
  * the colon is overloaded, both as job_id separater within a set of
- * depend jobs, and as the server:port separater.  Ugh!
+ *	depend jobs, and as the server:port separater. Ugh!
+ *
+ *	This code is horribly inefficient, because we have to walk the length of d, when called in a tight loop. We are
+ *	trying to replace this with cat_jobsvr.
  */
-
+#if 0
 static void cpy_jobsvr(
 
   char *d,
@@ -1812,6 +1888,71 @@ static void cpy_jobsvr(
 
   return;
   }  /* END cpy_jobsvr() */
+#endif /* 0 */
+
+/*
+ *  cat_jobsvr() - a version of strcat() that watches for an embedded colon
+ *	and escapes it with a leading blackslash.  This is needed because
+ *	the colon is overloaded, both as job_id separater within a set of
+ *	depend jobs, and as the server:port separater. Ugh!
+ */
+
+static void cat_jobsvr(
+
+  char **Dest,
+  char *Src)
+
+  {
+  char *d;
+
+  if (Dest == NULL)
+    return;
+
+  d = *Dest;
+
+  while (*Src) 
+    {
+    if (*Src == ':')
+      *d++ = '\\';
+
+    *d++ = *Src++;
+    }
+
+  *d = '\0';
+
+  *Dest = d;
+
+  return;
+  }
+
+
+/*
+ * fast_strcat() - an improved version of strcat() that is more efficient in
+ * a tight loop
+ */
+
+static void fast_strcat(
+
+  char **Dest,
+  char  *Src)
+
+  {
+  char *d;
+
+  if (Dest == NULL)
+    return;
+
+  d = *Dest;
+
+  while (*Src)
+    *d++ = *Src++;
+
+  *d = '\0';
+
+  *Dest = d;
+
+  return;
+  }
 
 
 
@@ -1876,12 +2017,14 @@ static int dup_depend(
  */
 /*ARGSUSED*/
 
-int encode_depend(attr, phead, atname, rsname, mode)
-attribute     *attr; /* ptr to attribute to encode */
-tlist_head     *phead; /* ptr to head of attrlist list */
-char       *atname; /* attribute name */
-char       *rsname; /* resource name or null */
-int        mode; /* encode mode, unused here */
+int encode_depend(
+
+  attribute    *attr,   /* ptr to attribute to encode */
+  tlist_head   *phead,  /* ptr to head of attrlist list */
+  char	       *atname, /* attribute name */
+  char	       *rsname, /* resource name or null */
+  int           mode)   /* encode mode, unused here */
+
   {
   int      ct = 0;
   char      cvtbuf[22];
@@ -1897,6 +2040,9 @@ int        mode; /* encode mode, unused here */
 
   struct dependnames *pn;
 
+  char *BPtr = 0;
+  int   BSpace = -1;
+
   if (!attr)
     return (-1);
 
@@ -1914,7 +2060,9 @@ int        mode; /* encode mode, unused here */
     {
     if ((nxdp->dp_type == JOB_DEPEND_TYPE_SYNCCT) ||
         (nxdp->dp_type == JOB_DEPEND_TYPE_ON))
-      ct += 30;   /* a guess at a reasonable amt of spece */
+      {
+      ct += 30;   /* a guess at a reasonable amt of space */
+      }
     else
       {
       ct += 12; /* for longest type */
@@ -1935,45 +2083,51 @@ int        mode; /* encode mode, unused here */
 
   *pal->al_value = '\0';
 
-  for (nxdp = pdp; nxdp; nxdp = (struct depend *)GET_NEXT(nxdp->dp_link))
+  BPtr = pal->al_value;
+  BSpace = pal->al_tsize;  /* this is actually a little larger than the actual buffer */
+
+	for (nxdp = pdp; nxdp; nxdp = (struct depend *)GET_NEXT(nxdp->dp_link))
     {
-    if ((nxdp->dp_type != JOB_DEPEND_TYPE_SYNCCT) &&
-        (nxdp->dp_type != JOB_DEPEND_TYPE_ON)       &&
-        !(pdjb = (struct depend_job *)GET_NEXT(nxdp->dp_jobs)))
-      continue; /* no value, skip this one */
-
-    if (numdep > 0)
-      strcat(pal->al_value, ","); /* comma between */
-
-    pn = &dependnames[nxdp->dp_type];
-
-    strcat(pal->al_value, pn->name);
-
-    if ((pn->type == JOB_DEPEND_TYPE_SYNCCT) ||
-        (pn->type == JOB_DEPEND_TYPE_ON))
+		if ((nxdp->dp_type != JOB_DEPEND_TYPE_SYNCCT) &&
+		    (nxdp->dp_type != JOB_DEPEND_TYPE_ON)       &&
+		    !(pdjb = (struct depend_job *)GET_NEXT(nxdp->dp_jobs)))
       {
-      sprintf(cvtbuf, ":%d", nxdp->dp_numexp);
-      strcat(pal->al_value, cvtbuf);
+			continue;	/* no value, skip this one */
+      }
+
+		if (nxdp != pdp)
+      fast_strcat(&BPtr,",");  /* comma between */
+
+		pn = &dependnames[nxdp->dp_type];
+    fast_strcat(&BPtr,pn->name);
+
+		if ((pn->type == JOB_DEPEND_TYPE_SYNCCT) ||
+		    (pn->type == JOB_DEPEND_TYPE_ON))
+      {
+			sprintf(cvtbuf, ":%d", nxdp->dp_numexp);
+      fast_strcat(&BPtr,cvtbuf);
       }
     else
       {
-      while (pdjb)
+			while (pdjb)
         {
-        strcat(pal->al_value, ":");
-        cpy_jobsvr(pal->al_value, pdjb->dc_child);
+        fast_strcat(&BPtr,":");
+        cat_jobsvr(&BPtr,pdjb->dc_child);
 
         if (*pdjb->dc_svr != '\0')
           {
-          strcat(pal->al_value, "@");
-          cpy_jobsvr(pal->al_value, pdjb->dc_svr);
+          /* WARNING: do we need to escape colons here (we used to) */
+          fast_strcat(&BPtr,"@");
+
+          cat_jobsvr(&BPtr,pdjb->dc_svr);
           }
 
-        pdjb = (struct depend_job *)GET_NEXT(pdjb->dc_link);
-        }
-      }
+				pdjb = (struct depend_job *)GET_NEXT(pdjb->dc_link);
+			  } 
+		  }
 
-    ++numdep;
-    }
+		++numdep;
+	  }
 
   if (numdep)
     {
