@@ -799,7 +799,7 @@ attribute_def svr_attr_def[] =
       MGR_ONLY_SET,
       ATR_TYPE_LONG,
       PARENT_TYPE_SERVER
-  },
+  }, 
 
   /* SRV_ATR_LogFileMaxSize */
   {   ATTR_logfilemaxsize,      /* "log_file_max_size" */
@@ -827,6 +827,20 @@ attribute_def svr_attr_def[] =
       PARENT_TYPE_SERVER
   },
 
+  /* SVR_ATR_Log_Keep_Days */
+  {
+      ATTR_logkeepdays,          /* "log_keep_days" */
+      decode_l,
+      encode_l,
+      set_l,
+      comp_l,
+      free_null,
+      NULL_FUNC,
+      NO_USER_SET,
+      ATR_TYPE_LONG,
+      PARENT_TYPE_SERVER
+  },
+
   /* SVR_ATR_NextJobNumber */
   { ATTR_nextjobnum,
     decode_l,
@@ -905,6 +919,57 @@ attribute_def svr_attr_def[] =
       PARENT_TYPE_SERVER
   },
 
+  /* SRV_ATR_AcctKeepDays */
+  {   ATTR_acctkeepdays,      /* "accounting_keep_days" */
+    	decode_l,
+    	encode_l,
+    	set_l,
+    	comp_l,
+    	free_null,
+    	NULL_FUNC,
+    	NO_USER_SET,
+    	ATR_TYPE_LONG,
+    	PARENT_TYPE_SERVER
+  },
+
+  /* SRV_ATR_lockfile */
+  {	  ATTR_lockfile,		/* "lock_file" */
+    	decode_str,
+    	encode_str,
+    	set_str,
+    	comp_str,
+    	free_str,
+    	NULL_FUNC,
+    	MGR_ONLY_SET,
+    	ATR_TYPE_STR,
+    	PARENT_TYPE_SERVER
+  },
+
+  /* SRV_ATR_CredentialLifetime */
+  {   ATTR_credentiallifetime,  /* "credential_lifetime" */
+      decode_l,
+      encode_l,
+      set_l,
+      comp_l,
+      free_null,
+      NULL_FUNC,
+      MGR_ONLY_SET,
+      ATR_TYPE_LONG,
+      PARENT_TYPE_SERVER
+  },
+	
+  /* SRV_ATR_JobMustReport */
+  { ATTR_jobmustreport,      /* "job_must_report" */
+    	decode_b,
+    	encode_b,
+    	set_b,
+    	comp_b,
+    	free_null,
+    	NULL_FUNC,
+    	MGR_ONLY_SET,
+    	ATR_TYPE_LONG,
+    	PARENT_TYPE_SERVER
+  },
 
   /* site supplied server attribute definitions if any, see site_svr_attr_*.h  */
 #include "site_svr_attr_def.h"
