@@ -129,6 +129,7 @@ extern int               LOGLEVEL;
 extern int     addr_ok(pbs_net_t);
 extern void    bad_node_warning(pbs_net_t);
 extern ssize_t read_blocking_socket(int, void *, ssize_t);
+extern int get_num_connections();
 
 
 
@@ -384,10 +385,23 @@ int socket_to_handle(
 
     svr_conn[sock].cn_handle = i;
 
+    if (i >= (PBS_NET_MAX_CONNECTIONS/2))
+      {
+      sprintf(log_buffer,"internal socket table is half-full at %d (expected num_connections is %d)!",
+        i,
+        get_num_connections());
+
+      log_ext(-1,id,log_buffer,LOG_CRIT);
+      }
+
     return(i);
     }  /* END for (i) */
 
-  log_err(-1, id, "internal socket table full");
+  sprintf(log_buffer,"internal socket table full (%d) - num_connections is %d",
+    i,
+    get_num_connections());
+
+  log_ext(-1,id,log_buffer,LOG_ALERT);
 
   pbs_errno = PBSE_NOCONNECTS;
 
