@@ -438,11 +438,10 @@ int svr_enquejob(
       {
       pjob->ji_wattr[(int)JOB_ATR_etime].at_val.at_long = time_now;
       pjob->ji_wattr[(int)JOB_ATR_etime].at_flags |= ATR_VFLAG_SET;
-
-      /* notify the scheduler we have a new job */
-
-      svr_do_schedule = SCH_SCHEDULE_NEW;
       }
+      
+    /* notify the scheduler we have a new job */
+    svr_do_schedule = SCH_SCHEDULE_NEW;
     }
   else if (pque->qu_qs.qu_type == QTYPE_RoutePush)
     {
@@ -1103,7 +1102,8 @@ int svr_chkque(
     {
     /* 1a. if not already set, set up execution uid/gid/name */
 
-    if (!(pjob->ji_wattr[(int)JOB_ATR_euser].at_flags & ATR_VFLAG_SET))
+    if (!(pjob->ji_wattr[(int)JOB_ATR_euser].at_flags & ATR_VFLAG_SET) ||
+        !(pjob->ji_wattr[(int)JOB_ATR_egroup].at_flags & ATR_VFLAG_SET))
       {
       if ((i = set_jobexid(pjob, pjob->ji_wattr, EMsg)) != 0)
         {
